@@ -645,7 +645,7 @@ int create_ust_event(struct ust_app *app, struct ust_app_session *ua_sess,
 	ret = ustctl_create_event(app->sock, &ua_event->attr, ua_chan->obj,
 			&ua_event->obj);
 	if (ret < 0) {
-		if (ret == -EEXIST) {
+		if (ret == -EEXIST || ret == -EPERM) {
 			ret = 0;
 			goto error;
 		}
@@ -1479,7 +1479,7 @@ int ust_app_list_events(struct lttng_event **events)
 			}
 			memcpy(tmp[count].name, uiter.name, LTTNG_UST_SYM_NAME_LEN);
 			tmp[count].loglevel = uiter.loglevel;
-			tmp[count].type = LTTNG_UST_TRACEPOINT;
+			tmp[count].type = (enum lttng_event_type) LTTNG_UST_TRACEPOINT;
 			tmp[count].pid = app->pid;
 			tmp[count].enabled = -1;
 			count++;
